@@ -1,17 +1,18 @@
+from les_iterables import partition_tail
+
 from intentionally_blank.formatter import Formatter
-from intentionally_blank.les_iterables import partition_tail
-from intentionally_blank.text import split_indent, is_blank_line
+from intentionally_blank.text import split_indent, is_partitioned_line_blank
 
 
 class PythonLeadingFormatter(Formatter):
     """A trailing colon introduces a new block. Blank lines have leading white space.
     """
-    
+
     def format(self, lines):
         """
         Args:
             lines: An iterable series of strings, each with a newline terminator.
-        
+
         Yields:
             An iterable series of strings, each with a newline terminator.
         """
@@ -21,7 +22,7 @@ class PythonLeadingFormatter(Formatter):
         active_indent = ""
         for line in head:
             indent, text = split_indent(line)
-            if not is_blank_line(indent, text):
+            if not is_partitioned_line_blank(indent, text):
                 yield line
                 active_indent = indent
                 if line.strip().endswith(":"):
@@ -29,11 +30,11 @@ class PythonLeadingFormatter(Formatter):
             else:
                 assert line.endswith("\n")
                 yield f"{active_indent}\n"
-                
+
         # tail will contain at most one line
         for line in tail:
             indent, text = split_indent(line)
-            if not is_blank_line(indent, text):
+            if not is_partitioned_line_blank(indent, text):
                 yield line
             else:
                 end = "\n" if line.endswith("\n") else ""
@@ -41,4 +42,3 @@ class PythonLeadingFormatter(Formatter):
                     yield f"{active_indent}{end}"
                 else:
                     yield end
-        
\ No newline at end of file
