@@ -7,6 +7,19 @@ LEADING_PATTERN = r"^(\s*)(.*)$"
 LEADING_REGEX = re.compile(LEADING_PATTERN)
 
 
+def is_blank_line(line: str) -> bool:
+    """Determine whether a line contains any non-whitespace characters.
+
+    Args:
+        line: The string to be tested.
+
+    Returns:
+        True if the string is empty or contains only whitespace, otherwise False.
+    """
+    indent, text = split_indent(line)
+    return is_partitioned_line_blank(indent, text)
+
+
 def split_indent(line):
     m = LEADING_REGEX.match(line)
     assert m is not None
@@ -14,7 +27,16 @@ def split_indent(line):
     return indent, text
 
 
-def is_blank_line(index, text):
+def is_partitioned_line_blank(indent: str, text: str) -> bool:
+    """Determine whether an indent-partitioned line is blank.
+
+    Args:
+        indent: The leading indent of a line. May be empty.
+        text: Text following the leading indent. May be empty.
+
+    Returns:
+        True if no text follows the indent.
+    """
     return len(text) == 0
 
 
@@ -54,5 +76,5 @@ def split_on_newlines(s, keepends=False):
                 end = "\n"
         else:
             end = ""
-            
+
         yield f"{line}{end}"
\ No newline at end of file
